/**
 * Classe astratta Allineamento: rappresenta l'allineamento ottimo 
 * tra due sequenze di aminoacidi
 * 
 */
public abstract class Allineamento
{
    // instance variables
    private Sequenza a;
    private Sequenza b;
    private MatriceSostituzione mat;
    private PenalitGap pg;

    
    /**
     * Constructor for objects of class Allineamento                                                           
     */
    public Allineamento(Sequenza sequenza1, Sequenza sequenza2, MatriceSostituzione matrice, PenalitGap penalitGap) 
    {
        // initialise instance variables
        a = sequenza1;
        b = sequenza2;
        mat = matrice;
        pg = penalitGap;
    }
    

    /**
     * Metodo che restituisce la prima sequenza di aminoacidi
     * 
     */
    public Sequenza sequenza1()
    {
        return a;
    }

    /**
     * Metodo che restituisce la seconda sequenza di aminoacidi
     * 
     */
    public Sequenza sequenza2()
    {
        return b;
    }


    /**
     * Metodo che restituisce la matrice di sostituzione
     * 
     */
    public MatriceSostituzione matriceSostituzione()
    {
        return mat;
    }

    /**
     * Metodo che restituisce la penalit dei gap
     * 
     */
    public PenalitGap penalitGap()
    {
        return pg;
    }




    /**
     * Metodo astratto che calcola l'allineamento ottimo
     *
     */
    public abstract void eseguiAllineamento();

    /**
     * Metodo astratto che restituisce il punteggio massimo globale
     *
     * @return     il punteggio massimo
     */
    public abstract int maxPunteggio();
    
    


    /**
     * Metodo astratto che restituisce il percorso ottimo 
     *  (dalla matrice p dei percorsi)
     *
     * @return     array di Stringhe con tutti i percorsi ottimi
     */
    public abstract String[] percorsoOttimo();
    
     
}
