
/**
 * Classe PenalitGap: rappresenta il costo nell'introdurre un gap in un allineamento
 * 
 * tipicamente si usano
 * costo di creazione di un gap --- costo di estensione di un gap
 *                     7        ---    2
 *                     8        ---    2
 *                     9        ---    2
 *                    10        ---    1 
 *                    11        ---    1
 *                    12        ---    1
 * 
 */
public class PenalitGap
{
    // costanti per indicare il tipo di penalit:
    //    1 se ogni gap ha la stessa penalit; 
    //    2 se si distingue tra creazione del gap ed estensione del gap stesso
    public static final int FISSA = 1; 
    public static final int DIFFERENZIATA = 2;
    
    // instance variables 
    private int tipo;  // tipo di penalit
    private int d;     // costo di creazione del gap
    private int e;     // costo di estensione del gap
            
    /**
     * Constructor for objects of class PenalitGap
     */
    public PenalitGap(int costoCreazioneGap, int costoEstensioneGap)
    {
        // initialise instance variables
        d = costoCreazioneGap;
        e = costoEstensioneGap;
        if (d == e) 
           {tipo = FISSA;}
        else 
           {tipo = DIFFERENZIATA;}
    }

    /**
     * Metodo che ritorna il tipo di penalit usato
     * 
     * @return     il tipo di penalit
     */
    public int tipoPenalit()
    {
        return tipo;
    }
    
    /**
     * Metodo che ritorna la penalit di creazione di un gap
     * 
     * @return     il costo di creazione di un nuovo gap
     */
    public int costoCreazione()
    {
        return d;
    }

    /**
     * Metodo che ritorna la penalit di estensione di un gap
     * 
     * @return     il costo di estensione di un gap
     */
    public int costoEstensione()
    {
        return e;
    }
    
    /**
     * Metodo che descrive le penalit di gap sotto forma di stringa
     *
     * @return     stringa descrittiva 
     */
    public String toString()
    {
        if (tipo == FISSA)
           {return "costo gap = " + d;}
        else
           {return "costo gap = " + d + " + " + e;}
    }

}
