/**
 * classe Sequenza: rappresenta una proteina come sequenza di aminoacidi
 * 
 */
public class Sequenza
{
    // instance variables
    private String nome;
    private String a;  // la sequenza di aminoacidi
    private int[] b;  // gli indici numerici degli aminoacidi


     /**
     * Constructor for objects of class Sequenza
     */
    public Sequenza()
    {
        nome = "";
        a = "";
    }


    /**
     * Constructor for objects of class Sequenza
     */
    public Sequenza(String unNome)
    {
        nome = unNome;
        a = "";
    }

    /**
     * Metodo che azzera la sequenza di aminoacidi, 
     * lasciando inalterato il nome
     *
     */
    public void azzera()
    {
        a = "";
    }
    

    /**
     * Metodo che ritorna il nome della sequenza
     * 
     * @return    il nome della sequenza
     */
    public String leggiNome()
    {
        return nome;
    }
    
    /**
     * Metodo che imposta il nome della sequenza
     * 
     * @param  il nuovo nome della sequenza
     */
    public void impostaNome(String nuovoNome)
    {
        nome = nuovoNome;
    }
    
    
    /**
     * Metodo che ritorna la lunghezza della sequenza
     * 
     * @return    il nome della sequenza
     */
    public int lunghezza()
    {
        return a.length();
    }
    
    

    /**
     * Metodo che assegna un elenco di  aminoacidi alla sequenza
     * 
     * @param    l'elenco di aminoacidi da assegnare
     * @return   0 se tutto OK, -1 se ci sono errori negli aminoacidi
     */
    public int impostaAminoacidi(String elencoAminoacidi)
    {
        int esito = 0;
        elencoAminoacidi = elencoAminoacidi.trim();  //elimina eventuali spazi
        elencoAminoacidi = elencoAminoacidi.toUpperCase(); // converte in maiuscolo
        a = elencoAminoacidi;
        int n = a.length();
        b = new int[n];
        int i = 0;
        char c;
        String ordine = "ARNDCQEGHILKMFPSTWYV";
        while ((i < n) && (esito == 0))
           {  
              c = a.charAt(i);
              b[i] = ordine.indexOf(c);
              if (b[i] == -1)  // aminoacido non valido
                  { esito = -1; }   
              i++;
            }        
         return esito;   
     }



     /**
     * Metodo che ritorna la sequenza stampabile
     * 
     * @return    una stringa con il nome e la sequenza di aminoacidi
     */
    public String toString()
    {
        return nome + ":  " + a;
    }


     /**
     * Metodo che ritorna la sequenza 
     * 
     * @return    una stringa con la sequenza di aminoacidi
     */
    public String leggiSequenza()
    {
        return a;
    }
    

    /**
    * Metodo che ritorna l'i-esimo aminoacido della sequenza
    *
    * @param  i   la posizione 
    * @return     l'i-esimo aminoacido
    */
    public char aminoacido(int i)
    {
       // deve essere  (i < lunghezza())
          return a.charAt(i);
    }
 
 
    /**
    * Metodo che ritorna l'indice numerico dell'i-esimo aminoacido della sequenza
    *
    * @param  i   la posizione 
    * @return     l'indice numerico dell'i-esimo aminoacido
    */
    public int indiceAminoacido(int i)
    {
       // deve essere (i < lunghezza())
          return b[i];
    }
    
}
